### 0.10.10 {small}`2024-10-08`

```{rubric} Bug fixes
```
* fixes a bug with the parameter dict for `pp.neighbors` {pr}`270` {smaller}`G Pires`
* fixes a bug with the parameter dict for `pp.bbknn` {pr}`271` {smaller}`S Dicks`
